jtextfsm: A TextFSM fork, Python 3 compatible
==============================================

Installation:

.. code:: bash

    pip install jtextfsm

Usage:

.. code:: python

    import jtextfsm as textfsm

The original code:
TextFSM: https://code.google.com/p/textfsm
